@@ -75,9 +75,8 @@ class PTWorkstationsForm(NetBoxModelForm):
 
 
 class PTWorkstationsAssignmentForm(BootstrapMixin, forms.ModelForm):
-    tenant = DynamicModelChoiceField(
-        queryset=Tenant.objects.all(), required=True)
-    app_system = DynamicModelChoiceField(queryset=PTWorkstations.objects.all(), query_params={'tenant': '$tenant',})
+    # tenant = DynamicModelChoiceField(queryset=Tenant.objects.all(), required=True)
+    pt_workstations = DynamicModelChoiceField(queryset=PTWorkstations.objects.all()) # , query_params={'tenant': '$tenant',}
 
     class Meta:
         model = PTWorkstationsAssignment
