@@ -189,8 +189,7 @@ class PTUsersView(generic.ObjectView):
                 'rel'          : r.relation.name
             })
 
-        pt_workstations = PTWorkstationsAssignment.objects.filter(object_id=instance.id,
-                                                                  content_type=content_type_id)
+        pt_workstations = PTWorkstationsAssignment.objects.filter(object_id=instance.id, content_type=content_type_id)
         PTWorkstations = []
         for s in pt_workstations:
             PTWorkstations.append({
@@ -219,6 +218,7 @@ class PTUsersDeleteView(generic.ObjectDeleteView):
 
 # PTWorkstations
 
+
 class PTWorkstationsView(generic.ObjectView):
     queryset = models.PTWorkstations.objects.all()
     # template_name = 'ptuevents/ptworkstations.html'
